2. Data loading — machado 0.1.0 documentation

# 2. Data loading

The Chado schema heavily relies on Ontologies to integrate different datasets. Therefore it must be the first to load.

Inside the extras directory, there’s a file named sample.tar.gz that might be helpful. It contains a few small FASTA and GFF files, together with a README file with examples of command lines.

- 2.1. Ontologies
- 2.2. Taxonomy
- 2.3. Organism
- 2.4. Publication
- 2.5. FASTA
- 2.6. GFF
- 2.7. Feature additional info
- 2.8. Blast
- 2.9. InterproScan
- 2.10. OrthoMCL
- 2.11. RNA-seq
- 2.12. Coexpression